@@ -37,7 +37,6 @@
 #include <QDBusConnectionInterface>
 #include <QDBusInterface>
 #include <QDBusServiceWatcher>
-#include <QDBusPendingCall>
 
 #include <KDBusService>
 #include <kconfiggroup.h>
@@ -54,12 +53,7 @@
 
 Q_DECLARE_LOGGING_CATEGORY(KDED)
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 4, 0)
-// logging category for this framework, default: log stuff >= warning
 Q_LOGGING_CATEGORY(KDED, "kf5.kded", QtWarningMsg)
-#else
-Q_LOGGING_CATEGORY(KDED, "kf5.kded")
-#endif
 
 Kded *Kded::_self = nullptr;
 
@@ -539,7 +533,7 @@ void Kded::recreate(bool initial)
         recreateDone();
         if (delayedCheck) {
             // do a proper ksycoca check after a delay
-            QTimer::singleShot(60000, this, SLOT(runDelayedCheck()));
+            QTimer::singleShot(60000, this, &Kded::runDelayedCheck);
             m_needDelayedCheck = true;
             delayedCheck = false;
         } else {
@@ -777,28 +771,8 @@ extern "C" Q_DECL_EXPORT int kdemain(int argc, char *argv[])
         (void) new KUpdateD;    // Watch for updates
     }
 
-//NOTE: We are going to change how KDE starts and this certanly doesn't fit on the new design.
-#if defined Q_OS_LINUX || defined Q_OS_CYGWIN
-    // Tell KSplash that KDED has started
-    QDBusMessage ksplashProgressMessage = QDBusMessage::createMethodCall(QStringLiteral("org.kde.KSplash"),
-                                          QStringLiteral("/KSplash"),
-                                          QStringLiteral("org.kde.KSplash"),
-                                          QStringLiteral("setStage"));
-    ksplashProgressMessage.setArguments(QList<QVariant>() << QStringLiteral("kded"));
-    QDBusConnection::sessionBus().asyncCall(ksplashProgressMessage);
-#endif
-
     runKonfUpdate(); // Run it once.
 
-#if defined Q_OS_LINUX || defined Q_OS_CYGWIN
-    ksplashProgressMessage = QDBusMessage::createMethodCall(QStringLiteral("org.kde.KSplash"),
-                             QStringLiteral("/KSplash"),
-                             QStringLiteral("org.kde.KSplash"),
-                             QStringLiteral("setStage"));
-    ksplashProgressMessage.setArguments(QList<QVariant>() << QStringLiteral("confupdate"));
-    QDBusConnection::sessionBus().asyncCall(ksplashProgressMessage);
-#endif
-
     int result = app.exec(); // keep running
 
     delete kded;
